# SBIG STXL-6303 Driver

Developed and tested with the following conda environment:
```
conda create -n SBIG python=3.5 pip ipython jupyter ipykernel numpy scipy matplotlib future astropy pyyaml pandas requests
```
